@@ -42,6 +42,7 @@ DONE = "done"
 DONT_KNOW = "dont_know"
 DWTA = "DWTA"  # don't want to answer
 ERROR = "ERROR"
+ESTIMATED = "estimated"
 EVENING = "evening"
 FAILED_ELIGIBILITY = "failed eligibility"
 FALSE = "false"
@@ -81,6 +82,7 @@ LOW_PRIORITY = "low"
 MALE = "M"
 MALIGNANCY = "malignancy"
 MEDIUM_PRIORITY = "medium"
+MEASURED = "measured"
 MICROSCOPY = "microscopy"
 MOBILE_NUMBER = "mobile_no"
 MODIFIED = "modified"
@@ -187,3 +189,10 @@ WEEKDAYS = "weekdays"
 WEEKENDS = "weekends"
 YES = "Yes"
 YESTERDAY = "yesterday"
+
+# operators
+EQ = "="
+GT = ">"
+GTE = ">="
+LT = "<"
+LTE = "<="
